@@ -239,6 +239,7 @@ class NavItem(MPTTModel, Dated):
     )
     type = models.CharField(max_length=15, choices=TYPE, default=TYPE.menu)
     text = models.CharField(max_length=127, blank=True, null=True)
+    template = models.CharField(max_length=255, blank=True, null=True)
 
     parent = TreeForeignKey('self', null=True, blank=True,
         related_name='children')
@@ -252,6 +253,7 @@ class NavItem(MPTTModel, Dated):
 
     static_url = models.CharField(max_length=255, blank=True, null=True)
 
+
     @property
     def ordered_children(self):
         return self.children.order_by('order')
@@ -391,3 +393,6 @@ class PageContent(ContentBlock):
     class Meta:
         verbose_name = 'block of page content'
         verbose_name_plural = 'blocks of page content'
+
+
+from .caches import *
